@@ -13,7 +13,7 @@ from fabric import Connection, task
 from invoke import Collection  # noqa, re-export
 
 
-__version__ = "1.0.20201221"
+__version__ = "1.0.20201223"
 
 
 # I don't care, in this context.
@@ -199,7 +199,7 @@ def mm(ctx):
     run(
         ctx,
         "venv/bin/python manage.py makemessages -a --add-location file"
-        " -i venv -i htmlcov",
+        " -i venv -i htmlcov -i node_modules -i lib",
         replace_env=False,
     )
     run(
@@ -586,6 +586,18 @@ def _check_eslint(ctx):
     run(ctx, f'npx eslint "*.js" {config.app}/static')
 
 
+def _check_large_files(ctx, *, limit=500000):
+    out = run(ctx, "git diff-index --cached --name-only HEAD", hide=True).stdout.strip()
+    sizes = ((f, os.stat(f).st_size) for f in out.splitlines())
+    large = {f: size for f, size in sizes if size > limit}
+    if large:
+        files = ", ".join(
+            f"{f} ({size} bytes)"
+            for f, size in sorted(large.items(), key=lambda r: r[1])
+        )
+        terminate(f"Large files detected: {files}")
+
+
 def _check_branch(ctx):
     branch = run(ctx, "git rev-parse --abbrev-ref HEAD", hide=True).stdout.strip()
     if branch != config.branch:
@@ -607,6 +619,7 @@ def check(ctx):
     _check_django(ctx)
     _check_prettier(ctx)
     _check_eslint(ctx)
+    _check_large_files(ctx)
 
 
 def _fmt_prettier(ctx):
@@ -621,6 +634,10 @@ def _fmt_tox_style(ctx):
     run(ctx, "tox -e style")
 
 
+def _fmt_black(ctx):
+    run(ctx, "pipx run --spec 'black>=20.8b1' black .")
+
+
 def _fmt_isort(ctx):
     run(
         ctx,
@@ -630,15 +647,11 @@ def _fmt_isort(ctx):
     )
 
 
-def _fmt_black(ctx):
-    run(ctx, "pipx run --spec 'black>=20.8b1' black .")
-
-
 @task
 def fmt(ctx):
     """Format the code"""
-    _fmt_isort(ctx)
     _fmt_black(ctx)
+    _fmt_isort(ctx)
     _fmt_prettier(ctx)
 
 
